@@ -30,20 +30,23 @@ class CiscoStyleCli:
     then CiscoStyleCli shows the recommendation with help description.
     
     1. interactive cisco command line interface
-    csc = CiscoStyleCli()
+    from CiscoStyleCli import CiscoStyleCli
+    csc = CiscoStyleCli.CiscoStyleCli()
     csc.run()
         - show the prompt to get your command (interactive mode)
         - press enter key , this function will return
     
     2. endless interactive cisco command line interface
-    csc = CiscoStyleCli(infinite=True)
+    from CiscoStyleCli import CiscoStyleCli
+    csc = CiscoStyleCli.CiscoStyleCli(infinite=True)
     csc.run() 
         - it has infinite loop
         - show the prompt to get your command (interactive mode)
         - you can quit when you meet quit command or quit()
     
     3. non-interactive run command
-    csc = CiscoStyleCli()
+    from CiscoStyleCli import CiscoStyleCli
+    csc = CiscoStyleCli.CiscoStyleCli()
     csc.runCommand(cmd)
         - run your command (non-interactive mode)
     
@@ -77,6 +80,7 @@ class CiscoStyleCli:
         self.c = ''
         self.prompt = prompt
         self.remoteCmd = {}
+        self.remoteCmd['cmd'] = {}
         self.rulePrintFile = rulePrintFile
         self._setCliDefault()
         self.isUseDefaultCommon = isUseDefaultCommon
@@ -102,6 +106,7 @@ class CiscoStyleCli:
             list <CR> simple <CR>
 
         :code example:
+            from CiscoStyleCli import CiscoStyleCli
             csc = CiscoStyleCli.CiscoStyleCli()
             cmdTop = {}
             gethostCmd = csc.addCmd(cmdTop,'gethost','command',"", "gethosthelp")                                                            # level 1
@@ -192,6 +197,7 @@ class CiscoStyleCli:
             list <CR> simple <CR>
 
         :code example:
+            from CiscoStyleCli import CiscoStyleCli
             csc = CiscoStyleCli.CiscoStyleCli()
             cmdTop = {}
             gethostCmd = csc.addCmd(cmdTop,'gethost','command',"", "gethosthelp")                                                            # level 1
@@ -395,6 +401,7 @@ class CiscoStyleCli:
           and it will add 'list' and 'quit' command automatically if you do not set it.
         
         :code example:
+            from CiscoStyleCli import CiscoStyleCli
             csc = CiscoStyleCli.CiscoStyleCli()
             remoteCmd = {}
             gethostCmd = csc.addCmd(remoteCmd,'gethost','command',"", "gethosthelp")
